@@ -1,6 +1,6 @@
 # SNMP::Info::CiscoAgg
 #
-# Copyright (c) 2014 SNMP::Info Developers
+# Copyright (c) 2018 SNMP::Info Developers
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -43,7 +43,7 @@ use SNMP::Info::IEEE802dot3ad 'agg_ports_lag';
 
 use vars qw/$VERSION %MIBS %FUNCS %GLOBALS %MUNGE/;
 
-$VERSION = '3.49';
+$VERSION = '3.50';
 
 %MIBS = (
   %SNMP::Info::IEEE802dot3ad::MIBS,
@@ -52,9 +52,13 @@ $VERSION = '3.49';
 
 %GLOBALS = ();
 
-%FUNCS = ();
+%FUNCS = (
+  %SNMP::Info::IEEE802dot3ad::FUNCS,
+);
 
-%MUNGE = ();
+%MUNGE = (
+  %SNMP::Info::IEEE802dot3ad::MUNGE,
+);
 
 sub agg_ports_pagp {
   my $dev = shift;
@@ -147,4 +151,8 @@ automatically.
 
 =back
 
+=head2 Table Methods imported from SNMP::Info::IEEE802dot3ad
+
+See documentation in L<SNMP::Info::IEEE802dot3ad> for details.
+
 =cut
