@@ -1,6 +1,6 @@
 # SNMP::Info::Layer3::H3C
 #
-# Copyright (c) 2012 Jeroen van Ingen
+# Copyright (c) 2018 Jeroen van Ingen
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -47,7 +47,7 @@ use SNMP::Info::IEEE802dot3ad 'agg_ports_lag';
 
 use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %MUNGE/;
 
-$VERSION = '3.49';
+$VERSION = '3.50';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
@@ -71,12 +71,14 @@ $VERSION = '3.49';
 %FUNCS = (
     %SNMP::Info::Layer3::FUNCS,
     %SNMP::Info::LLDP::FUNCS,
+    %SNMP::Info::IEEE802dot3ad::FUNCS,
     i_duplex_admin => 'hh3cifEthernetDuplex',
 );
 
 %MUNGE = (
     %SNMP::Info::Layer3::MUNGE,
     %SNMP::Info::LLDP::MUNGE,
+    %SNMP::Info::IEEE802dot3ad::MUNGE,
 );
 
 sub vendor {
@@ -265,4 +267,8 @@ See documentation in L<SNMP::Info::Layer3> for details.
 
 See documentation in L<SNMP::Info::LLDP> for details.
 
+=head2 Table Methods imported from SNMP::Info::IEEE802dot3ad
+
+See documentation in L<SNMP::Info::IEEE802dot3ad> for details.
+
 =cut
